@@ -192,7 +192,7 @@ class WorkDocsClient:
         OrganizationId: str = None,
         EmailAddress: str = None,
         TimeZoneId: str = None,
-        StorageRule: StorageRuleTypeTypeDef = None,
+        StorageRule: "StorageRuleTypeTypeDef" = None,
         AuthenticationToken: str = None,
     ) -> CreateUserResponseTypeDef:
         """
@@ -526,7 +526,7 @@ class WorkDocsClient:
         GivenName: str = None,
         Surname: str = None,
         Type: Literal["USER", "ADMIN", "POWERUSER", "MINIMALUSER", "WORKSPACESUSER"] = None,
-        StorageRule: StorageRuleTypeTypeDef = None,
+        StorageRule: "StorageRuleTypeTypeDef" = None,
         TimeZoneId: str = None,
         Locale: Literal[
             "en", "fr", "ko", "de", "es", "ja", "ru", "zh_CN", "zh_TW", "pt_BR", "default"
