@@ -3,9 +3,9 @@ Main interface for workdocs service type definitions.
 
 Usage::
 
-    from mypy_boto3.workdocs.type_defs import StorageRuleTypeTypeDef
+    from mypy_boto3.workdocs.type_defs import ActivityTypeDef
 
-    data: StorageRuleTypeTypeDef = {...}
+    data: ActivityTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,48 +22,48 @@ else:
 
 
 __all__ = (
+    "ActivityTypeDef",
+    "CommentMetadataTypeDef",
+    "CommentTypeDef",
+    "DocumentMetadataTypeDef",
+    "DocumentVersionMetadataTypeDef",
+    "FolderMetadataTypeDef",
+    "GroupMetadataTypeDef",
+    "ParticipantsTypeDef",
+    "PermissionInfoTypeDef",
+    "PrincipalTypeDef",
+    "ResourceMetadataTypeDef",
+    "ResourcePathComponentTypeDef",
+    "ResourcePathTypeDef",
+    "ShareResultTypeDef",
     "StorageRuleTypeTypeDef",
+    "SubscriptionTypeDef",
+    "UploadMetadataTypeDef",
+    "UserMetadataTypeDef",
     "UserStorageMetadataTypeDef",
     "UserTypeDef",
     "ActivateUserResponseTypeDef",
-    "ShareResultTypeDef",
     "AddResourcePermissionsResponseTypeDef",
-    "CommentTypeDef",
     "CreateCommentResponseTypeDef",
-    "FolderMetadataTypeDef",
     "CreateFolderResponseTypeDef",
-    "SubscriptionTypeDef",
     "CreateNotificationSubscriptionResponseTypeDef",
     "CreateUserResponseTypeDef",
-    "CommentMetadataTypeDef",
-    "GroupMetadataTypeDef",
-    "UserMetadataTypeDef",
-    "ParticipantsTypeDef",
-    "ResourceMetadataTypeDef",
-    "ActivityTypeDef",
     "DescribeActivitiesResponseTypeDef",
     "DescribeCommentsResponseTypeDef",
-    "DocumentVersionMetadataTypeDef",
     "DescribeDocumentVersionsResponseTypeDef",
-    "DocumentMetadataTypeDef",
     "DescribeFolderContentsResponseTypeDef",
     "DescribeGroupsResponseTypeDef",
     "DescribeNotificationSubscriptionsResponseTypeDef",
-    "PermissionInfoTypeDef",
-    "PrincipalTypeDef",
     "DescribeResourcePermissionsResponseTypeDef",
     "DescribeRootFoldersResponseTypeDef",
     "DescribeUsersResponseTypeDef",
     "GetCurrentUserResponseTypeDef",
-    "ResourcePathComponentTypeDef",
-    "ResourcePathTypeDef",
     "GetDocumentPathResponseTypeDef",
     "GetDocumentResponseTypeDef",
     "GetDocumentVersionResponseTypeDef",
     "GetFolderPathResponseTypeDef",
     "GetFolderResponseTypeDef",
     "GetResourcesResponseTypeDef",
-    "UploadMetadataTypeDef",
     "InitiateDocumentVersionUploadResponseTypeDef",
     "NotificationOptionsTypeDef",
     "PaginatorConfigTypeDef",
@@ -71,166 +71,6 @@ __all__ = (
     "UpdateUserResponseTypeDef",
 )
 
-StorageRuleTypeTypeDef = TypedDict(
-    "StorageRuleTypeTypeDef",
-    {"StorageAllocatedInBytes": int, "StorageType": Literal["UNLIMITED", "QUOTA"]},
-    total=False,
-)
-
-UserStorageMetadataTypeDef = TypedDict(
-    "UserStorageMetadataTypeDef",
-    {"StorageUtilizedInBytes": int, "StorageRule": StorageRuleTypeTypeDef},
-    total=False,
-)
-
-UserTypeDef = TypedDict(
-    "UserTypeDef",
-    {
-        "Id": str,
-        "Username": str,
-        "EmailAddress": str,
-        "GivenName": str,
-        "Surname": str,
-        "OrganizationId": str,
-        "RootFolderId": str,
-        "RecycleBinFolderId": str,
-        "Status": Literal["ACTIVE", "INACTIVE", "PENDING"],
-        "Type": Literal["USER", "ADMIN", "POWERUSER", "MINIMALUSER", "WORKSPACESUSER"],
-        "CreatedTimestamp": datetime,
-        "ModifiedTimestamp": datetime,
-        "TimeZoneId": str,
-        "Locale": Literal[
-            "en", "fr", "ko", "de", "es", "ja", "ru", "zh_CN", "zh_TW", "pt_BR", "default"
-        ],
-        "Storage": UserStorageMetadataTypeDef,
-    },
-    total=False,
-)
-
-ActivateUserResponseTypeDef = TypedDict(
-    "ActivateUserResponseTypeDef", {"User": UserTypeDef}, total=False
-)
-
-ShareResultTypeDef = TypedDict(
-    "ShareResultTypeDef",
-    {
-        "PrincipalId": str,
-        "InviteePrincipalId": str,
-        "Role": Literal["VIEWER", "CONTRIBUTOR", "OWNER", "COOWNER"],
-        "Status": Literal["SUCCESS", "FAILURE"],
-        "ShareId": str,
-        "StatusMessage": str,
-    },
-    total=False,
-)
-
-AddResourcePermissionsResponseTypeDef = TypedDict(
-    "AddResourcePermissionsResponseTypeDef", {"ShareResults": List[ShareResultTypeDef]}, total=False
-)
-
-_RequiredCommentTypeDef = TypedDict("_RequiredCommentTypeDef", {"CommentId": str})
-_OptionalCommentTypeDef = TypedDict(
-    "_OptionalCommentTypeDef",
-    {
-        "ParentId": str,
-        "ThreadId": str,
-        "Text": str,
-        "Contributor": UserTypeDef,
-        "CreatedTimestamp": datetime,
-        "Status": Literal["DRAFT", "PUBLISHED", "DELETED"],
-        "Visibility": Literal["PUBLIC", "PRIVATE"],
-        "RecipientId": str,
-    },
-    total=False,
-)
-
-
-class CommentTypeDef(_RequiredCommentTypeDef, _OptionalCommentTypeDef):
-    pass
-
-
-CreateCommentResponseTypeDef = TypedDict(
-    "CreateCommentResponseTypeDef", {"Comment": CommentTypeDef}, total=False
-)
-
-FolderMetadataTypeDef = TypedDict(
-    "FolderMetadataTypeDef",
-    {
-        "Id": str,
-        "Name": str,
-        "CreatorId": str,
-        "ParentFolderId": str,
-        "CreatedTimestamp": datetime,
-        "ModifiedTimestamp": datetime,
-        "ResourceState": Literal["ACTIVE", "RESTORING", "RECYCLING", "RECYCLED"],
-        "Signature": str,
-        "Labels": List[str],
-        "Size": int,
-        "LatestVersionSize": int,
-    },
-    total=False,
-)
-
-CreateFolderResponseTypeDef = TypedDict(
-    "CreateFolderResponseTypeDef", {"Metadata": FolderMetadataTypeDef}, total=False
-)
-
-SubscriptionTypeDef = TypedDict(
-    "SubscriptionTypeDef",
-    {"SubscriptionId": str, "EndPoint": str, "Protocol": Literal["HTTPS"]},
-    total=False,
-)
-
-CreateNotificationSubscriptionResponseTypeDef = TypedDict(
-    "CreateNotificationSubscriptionResponseTypeDef",
-    {"Subscription": SubscriptionTypeDef},
-    total=False,
-)
-
-CreateUserResponseTypeDef = TypedDict(
-    "CreateUserResponseTypeDef", {"User": UserTypeDef}, total=False
-)
-
-CommentMetadataTypeDef = TypedDict(
-    "CommentMetadataTypeDef",
-    {
-        "CommentId": str,
-        "Contributor": UserTypeDef,
-        "CreatedTimestamp": datetime,
-        "CommentStatus": Literal["DRAFT", "PUBLISHED", "DELETED"],
-        "RecipientId": str,
-    },
-    total=False,
-)
-
-GroupMetadataTypeDef = TypedDict("GroupMetadataTypeDef", {"Id": str, "Name": str}, total=False)
-
-UserMetadataTypeDef = TypedDict(
-    "UserMetadataTypeDef",
-    {"Id": str, "Username": str, "GivenName": str, "Surname": str, "EmailAddress": str},
-    total=False,
-)
-
-ParticipantsTypeDef = TypedDict(
-    "ParticipantsTypeDef",
-    {"Users": List[UserMetadataTypeDef], "Groups": List[GroupMetadataTypeDef]},
-    total=False,
-)
-
-ResourceMetadataTypeDef = TypedDict(
-    "ResourceMetadataTypeDef",
-    {
-        "Type": Literal["FOLDER", "DOCUMENT"],
-        "Name": str,
-        "OriginalName": str,
-        "Id": str,
-        "VersionId": str,
-        "Owner": UserMetadataTypeDef,
-        "ParentId": str,
-    },
-    total=False,
-)
-
 ActivityTypeDef = TypedDict(
     "ActivityTypeDef",
     {
@@ -272,24 +112,60 @@ ActivityTypeDef = TypedDict(
         "TimeStamp": datetime,
         "IsIndirectActivity": bool,
         "OrganizationId": str,
-        "Initiator": UserMetadataTypeDef,
-        "Participants": ParticipantsTypeDef,
-        "ResourceMetadata": ResourceMetadataTypeDef,
-        "OriginalParent": ResourceMetadataTypeDef,
-        "CommentMetadata": CommentMetadataTypeDef,
+        "Initiator": "UserMetadataTypeDef",
+        "Participants": "ParticipantsTypeDef",
+        "ResourceMetadata": "ResourceMetadataTypeDef",
+        "OriginalParent": "ResourceMetadataTypeDef",
+        "CommentMetadata": "CommentMetadataTypeDef",
     },
     total=False,
 )
 
-DescribeActivitiesResponseTypeDef = TypedDict(
-    "DescribeActivitiesResponseTypeDef",
-    {"UserActivities": List[ActivityTypeDef], "Marker": str},
+CommentMetadataTypeDef = TypedDict(
+    "CommentMetadataTypeDef",
+    {
+        "CommentId": str,
+        "Contributor": "UserTypeDef",
+        "CreatedTimestamp": datetime,
+        "CommentStatus": Literal["DRAFT", "PUBLISHED", "DELETED"],
+        "RecipientId": str,
+    },
     total=False,
 )
 
-DescribeCommentsResponseTypeDef = TypedDict(
-    "DescribeCommentsResponseTypeDef",
-    {"Comments": List[CommentTypeDef], "Marker": str},
+_RequiredCommentTypeDef = TypedDict("_RequiredCommentTypeDef", {"CommentId": str})
+_OptionalCommentTypeDef = TypedDict(
+    "_OptionalCommentTypeDef",
+    {
+        "ParentId": str,
+        "ThreadId": str,
+        "Text": str,
+        "Contributor": "UserTypeDef",
+        "CreatedTimestamp": datetime,
+        "Status": Literal["DRAFT", "PUBLISHED", "DELETED"],
+        "Visibility": Literal["PUBLIC", "PRIVATE"],
+        "RecipientId": str,
+    },
+    total=False,
+)
+
+
+class CommentTypeDef(_RequiredCommentTypeDef, _OptionalCommentTypeDef):
+    pass
+
+
+DocumentMetadataTypeDef = TypedDict(
+    "DocumentMetadataTypeDef",
+    {
+        "Id": str,
+        "CreatorId": str,
+        "ParentFolderId": str,
+        "CreatedTimestamp": datetime,
+        "ModifiedTimestamp": datetime,
+        "LatestVersionMetadata": "DocumentVersionMetadataTypeDef",
+        "ResourceState": Literal["ACTIVE", "RESTORING", "RECYCLING", "RECYCLED"],
+        "Labels": List[str],
+    },
     total=False,
 )
 
@@ -313,46 +189,29 @@ DocumentVersionMetadataTypeDef = TypedDict(
     total=False,
 )
 
-DescribeDocumentVersionsResponseTypeDef = TypedDict(
-    "DescribeDocumentVersionsResponseTypeDef",
-    {"DocumentVersions": List[DocumentVersionMetadataTypeDef], "Marker": str},
-    total=False,
-)
-
-DocumentMetadataTypeDef = TypedDict(
-    "DocumentMetadataTypeDef",
+FolderMetadataTypeDef = TypedDict(
+    "FolderMetadataTypeDef",
     {
         "Id": str,
+        "Name": str,
         "CreatorId": str,
         "ParentFolderId": str,
         "CreatedTimestamp": datetime,
         "ModifiedTimestamp": datetime,
-        "LatestVersionMetadata": DocumentVersionMetadataTypeDef,
         "ResourceState": Literal["ACTIVE", "RESTORING", "RECYCLING", "RECYCLED"],
+        "Signature": str,
         "Labels": List[str],
+        "Size": int,
+        "LatestVersionSize": int,
     },
     total=False,
 )
 
-DescribeFolderContentsResponseTypeDef = TypedDict(
-    "DescribeFolderContentsResponseTypeDef",
-    {
-        "Folders": List[FolderMetadataTypeDef],
-        "Documents": List[DocumentMetadataTypeDef],
-        "Marker": str,
-    },
-    total=False,
-)
+GroupMetadataTypeDef = TypedDict("GroupMetadataTypeDef", {"Id": str, "Name": str}, total=False)
 
-DescribeGroupsResponseTypeDef = TypedDict(
-    "DescribeGroupsResponseTypeDef",
-    {"Groups": List[GroupMetadataTypeDef], "Marker": str},
-    total=False,
-)
-
-DescribeNotificationSubscriptionsResponseTypeDef = TypedDict(
-    "DescribeNotificationSubscriptionsResponseTypeDef",
-    {"Subscriptions": List[SubscriptionTypeDef], "Marker": str},
+ParticipantsTypeDef = TypedDict(
+    "ParticipantsTypeDef",
+    {"Users": List["UserMetadataTypeDef"], "Groups": List["GroupMetadataTypeDef"]},
     total=False,
 )
 
@@ -370,84 +229,227 @@ PrincipalTypeDef = TypedDict(
     {
         "Id": str,
         "Type": Literal["USER", "GROUP", "INVITE", "ANONYMOUS", "ORGANIZATION"],
-        "Roles": List[PermissionInfoTypeDef],
+        "Roles": List["PermissionInfoTypeDef"],
     },
     total=False,
 )
 
-DescribeResourcePermissionsResponseTypeDef = TypedDict(
-    "DescribeResourcePermissionsResponseTypeDef",
-    {"Principals": List[PrincipalTypeDef], "Marker": str},
+ResourceMetadataTypeDef = TypedDict(
+    "ResourceMetadataTypeDef",
+    {
+        "Type": Literal["FOLDER", "DOCUMENT"],
+        "Name": str,
+        "OriginalName": str,
+        "Id": str,
+        "VersionId": str,
+        "Owner": "UserMetadataTypeDef",
+        "ParentId": str,
+    },
     total=False,
 )
 
-DescribeRootFoldersResponseTypeDef = TypedDict(
-    "DescribeRootFoldersResponseTypeDef",
-    {"Folders": List[FolderMetadataTypeDef], "Marker": str},
-    total=False,
-)
-
-DescribeUsersResponseTypeDef = TypedDict(
-    "DescribeUsersResponseTypeDef",
-    {"Users": List[UserTypeDef], "TotalNumberOfUsers": int, "Marker": str},
-    total=False,
-)
-
-GetCurrentUserResponseTypeDef = TypedDict(
-    "GetCurrentUserResponseTypeDef", {"User": UserTypeDef}, total=False
-)
-
 ResourcePathComponentTypeDef = TypedDict(
     "ResourcePathComponentTypeDef", {"Id": str, "Name": str}, total=False
 )
 
 ResourcePathTypeDef = TypedDict(
-    "ResourcePathTypeDef", {"Components": List[ResourcePathComponentTypeDef]}, total=False
+    "ResourcePathTypeDef", {"Components": List["ResourcePathComponentTypeDef"]}, total=False
 )
 
-GetDocumentPathResponseTypeDef = TypedDict(
-    "GetDocumentPathResponseTypeDef", {"Path": ResourcePathTypeDef}, total=False
-)
-
-GetDocumentResponseTypeDef = TypedDict(
-    "GetDocumentResponseTypeDef",
-    {"Metadata": DocumentMetadataTypeDef, "CustomMetadata": Dict[str, str]},
-    total=False,
-)
-
-GetDocumentVersionResponseTypeDef = TypedDict(
-    "GetDocumentVersionResponseTypeDef",
-    {"Metadata": DocumentVersionMetadataTypeDef, "CustomMetadata": Dict[str, str]},
-    total=False,
-)
-
-GetFolderPathResponseTypeDef = TypedDict(
-    "GetFolderPathResponseTypeDef", {"Path": ResourcePathTypeDef}, total=False
-)
-
-GetFolderResponseTypeDef = TypedDict(
-    "GetFolderResponseTypeDef",
-    {"Metadata": FolderMetadataTypeDef, "CustomMetadata": Dict[str, str]},
-    total=False,
-)
-
-GetResourcesResponseTypeDef = TypedDict(
-    "GetResourcesResponseTypeDef",
+ShareResultTypeDef = TypedDict(
+    "ShareResultTypeDef",
     {
-        "Folders": List[FolderMetadataTypeDef],
-        "Documents": List[DocumentMetadataTypeDef],
-        "Marker": str,
+        "PrincipalId": str,
+        "InviteePrincipalId": str,
+        "Role": Literal["VIEWER", "CONTRIBUTOR", "OWNER", "COOWNER"],
+        "Status": Literal["SUCCESS", "FAILURE"],
+        "ShareId": str,
+        "StatusMessage": str,
     },
     total=False,
 )
 
+StorageRuleTypeTypeDef = TypedDict(
+    "StorageRuleTypeTypeDef",
+    {"StorageAllocatedInBytes": int, "StorageType": Literal["UNLIMITED", "QUOTA"]},
+    total=False,
+)
+
+SubscriptionTypeDef = TypedDict(
+    "SubscriptionTypeDef",
+    {"SubscriptionId": str, "EndPoint": str, "Protocol": Literal["HTTPS"]},
+    total=False,
+)
+
 UploadMetadataTypeDef = TypedDict(
     "UploadMetadataTypeDef", {"UploadUrl": str, "SignedHeaders": Dict[str, str]}, total=False
 )
 
+UserMetadataTypeDef = TypedDict(
+    "UserMetadataTypeDef",
+    {"Id": str, "Username": str, "GivenName": str, "Surname": str, "EmailAddress": str},
+    total=False,
+)
+
+UserStorageMetadataTypeDef = TypedDict(
+    "UserStorageMetadataTypeDef",
+    {"StorageUtilizedInBytes": int, "StorageRule": "StorageRuleTypeTypeDef"},
+    total=False,
+)
+
+UserTypeDef = TypedDict(
+    "UserTypeDef",
+    {
+        "Id": str,
+        "Username": str,
+        "EmailAddress": str,
+        "GivenName": str,
+        "Surname": str,
+        "OrganizationId": str,
+        "RootFolderId": str,
+        "RecycleBinFolderId": str,
+        "Status": Literal["ACTIVE", "INACTIVE", "PENDING"],
+        "Type": Literal["USER", "ADMIN", "POWERUSER", "MINIMALUSER", "WORKSPACESUSER"],
+        "CreatedTimestamp": datetime,
+        "ModifiedTimestamp": datetime,
+        "TimeZoneId": str,
+        "Locale": Literal[
+            "en", "fr", "ko", "de", "es", "ja", "ru", "zh_CN", "zh_TW", "pt_BR", "default"
+        ],
+        "Storage": "UserStorageMetadataTypeDef",
+    },
+    total=False,
+)
+
+ActivateUserResponseTypeDef = TypedDict(
+    "ActivateUserResponseTypeDef", {"User": "UserTypeDef"}, total=False
+)
+
+AddResourcePermissionsResponseTypeDef = TypedDict(
+    "AddResourcePermissionsResponseTypeDef",
+    {"ShareResults": List["ShareResultTypeDef"]},
+    total=False,
+)
+
+CreateCommentResponseTypeDef = TypedDict(
+    "CreateCommentResponseTypeDef", {"Comment": "CommentTypeDef"}, total=False
+)
+
+CreateFolderResponseTypeDef = TypedDict(
+    "CreateFolderResponseTypeDef", {"Metadata": "FolderMetadataTypeDef"}, total=False
+)
+
+CreateNotificationSubscriptionResponseTypeDef = TypedDict(
+    "CreateNotificationSubscriptionResponseTypeDef",
+    {"Subscription": "SubscriptionTypeDef"},
+    total=False,
+)
+
+CreateUserResponseTypeDef = TypedDict(
+    "CreateUserResponseTypeDef", {"User": "UserTypeDef"}, total=False
+)
+
+DescribeActivitiesResponseTypeDef = TypedDict(
+    "DescribeActivitiesResponseTypeDef",
+    {"UserActivities": List["ActivityTypeDef"], "Marker": str},
+    total=False,
+)
+
+DescribeCommentsResponseTypeDef = TypedDict(
+    "DescribeCommentsResponseTypeDef",
+    {"Comments": List["CommentTypeDef"], "Marker": str},
+    total=False,
+)
+
+DescribeDocumentVersionsResponseTypeDef = TypedDict(
+    "DescribeDocumentVersionsResponseTypeDef",
+    {"DocumentVersions": List["DocumentVersionMetadataTypeDef"], "Marker": str},
+    total=False,
+)
+
+DescribeFolderContentsResponseTypeDef = TypedDict(
+    "DescribeFolderContentsResponseTypeDef",
+    {
+        "Folders": List["FolderMetadataTypeDef"],
+        "Documents": List["DocumentMetadataTypeDef"],
+        "Marker": str,
+    },
+    total=False,
+)
+
+DescribeGroupsResponseTypeDef = TypedDict(
+    "DescribeGroupsResponseTypeDef",
+    {"Groups": List["GroupMetadataTypeDef"], "Marker": str},
+    total=False,
+)
+
+DescribeNotificationSubscriptionsResponseTypeDef = TypedDict(
+    "DescribeNotificationSubscriptionsResponseTypeDef",
+    {"Subscriptions": List["SubscriptionTypeDef"], "Marker": str},
+    total=False,
+)
+
+DescribeResourcePermissionsResponseTypeDef = TypedDict(
+    "DescribeResourcePermissionsResponseTypeDef",
+    {"Principals": List["PrincipalTypeDef"], "Marker": str},
+    total=False,
+)
+
+DescribeRootFoldersResponseTypeDef = TypedDict(
+    "DescribeRootFoldersResponseTypeDef",
+    {"Folders": List["FolderMetadataTypeDef"], "Marker": str},
+    total=False,
+)
+
+DescribeUsersResponseTypeDef = TypedDict(
+    "DescribeUsersResponseTypeDef",
+    {"Users": List["UserTypeDef"], "TotalNumberOfUsers": int, "Marker": str},
+    total=False,
+)
+
+GetCurrentUserResponseTypeDef = TypedDict(
+    "GetCurrentUserResponseTypeDef", {"User": "UserTypeDef"}, total=False
+)
+
+GetDocumentPathResponseTypeDef = TypedDict(
+    "GetDocumentPathResponseTypeDef", {"Path": "ResourcePathTypeDef"}, total=False
+)
+
+GetDocumentResponseTypeDef = TypedDict(
+    "GetDocumentResponseTypeDef",
+    {"Metadata": "DocumentMetadataTypeDef", "CustomMetadata": Dict[str, str]},
+    total=False,
+)
+
+GetDocumentVersionResponseTypeDef = TypedDict(
+    "GetDocumentVersionResponseTypeDef",
+    {"Metadata": "DocumentVersionMetadataTypeDef", "CustomMetadata": Dict[str, str]},
+    total=False,
+)
+
+GetFolderPathResponseTypeDef = TypedDict(
+    "GetFolderPathResponseTypeDef", {"Path": "ResourcePathTypeDef"}, total=False
+)
+
+GetFolderResponseTypeDef = TypedDict(
+    "GetFolderResponseTypeDef",
+    {"Metadata": "FolderMetadataTypeDef", "CustomMetadata": Dict[str, str]},
+    total=False,
+)
+
+GetResourcesResponseTypeDef = TypedDict(
+    "GetResourcesResponseTypeDef",
+    {
+        "Folders": List["FolderMetadataTypeDef"],
+        "Documents": List["DocumentMetadataTypeDef"],
+        "Marker": str,
+    },
+    total=False,
+)
+
 InitiateDocumentVersionUploadResponseTypeDef = TypedDict(
     "InitiateDocumentVersionUploadResponseTypeDef",
-    {"Metadata": DocumentMetadataTypeDef, "UploadMetadata": UploadMetadataTypeDef},
+    {"Metadata": "DocumentMetadataTypeDef", "UploadMetadata": "UploadMetadataTypeDef"},
     total=False,
 )
 
@@ -469,5 +471,5 @@ SharePrincipalTypeDef = TypedDict(
 )
 
 UpdateUserResponseTypeDef = TypedDict(
-    "UpdateUserResponseTypeDef", {"User": UserTypeDef}, total=False
+    "UpdateUserResponseTypeDef", {"User": "UserTypeDef"}, total=False
 )
